@@ -5,7 +5,7 @@ use strict;
 use warnings;
 BEGIN
   { our
-      $VERSION = substr '$$Version: 0.05 $$', 11, -3;
+      $VERSION = substr '$$Version: 0.06 $$', 11, -3;
   }
 
 require Exporter;
@@ -22,6 +22,8 @@ use enum qw
     NoSuchFile
     BadConfigFile
     BadPreset
+    NotImplemented
+    NotAllowedInPresets
   );
 
 # Export all Enums defined above.
